@@ -62,6 +62,7 @@ VERSIONS = [
     VersionSet(left="2.1", right="3", expected=-1),
     VersionSet(left="2.1", right="10", expected=-1),
     VersionSet(left="2.1", right="10.1", expected=-1),
+    VersionSet(left="2.1", right="1:1.0", expected=-1),
     VersionSet(left="3.0.beta2", right="1", expected=1),
     VersionSet(left="3.0.beta2", right="3.0", expected=-1),
     VersionSet(left="3.0.beta2", right="3.0.beta1", expected=1),
@@ -78,6 +79,8 @@ VERSIONS = [
     VersionSet(left="str12foo7", right="str13foo1", expected=-1),
     VersionSet(left="4.15.0-3", right="4.15.0-3~bpo10", expected=1),
     VersionSet(left="4.15.0-3bpo10", right="4.15.0-3~bpo10", expected=1),
+    VersionSet(left="1:1.0", right="2.1", expected=1),
+    VersionSet(left="42:2.1", right="10.1", expected=1),
 ]
 
 EXPECTED_TO_STR = {
@@ -108,10 +111,12 @@ UNSORTED = [
     "3.10.0-983.13.1.el11.x86_64",
     "1.0",
     "3.10.0-983.13.1.el7.x86_64",
+    "4:0.4",
     "4.15.0-3",
     "0.1.0",
     "1.0.1",
     "2.0",
+    "3:1.0",
     "3.10.0-1062.1.1.el6.x86_64",
     "4.15.0-3~bpo10",
     "3.10.0-983.13.1.el1.x86_64",
@@ -130,4 +135,6 @@ SORTED = [
     "3.10.0-1062.1.1.el7.x86_64",
     "4.15.0-3~bpo10",
     "4.15.0-3",
+    "3:1.0",
+    "4:0.4",
 ]
